pub struct ModifyOrder { /* private fields */ }Expand description
Order modification parameters.
Construct this request with ModifyOrder::builder, which requires at
least one replacement value and rejects non-positive replacement sizes.
Implementations
Sourceimpl ModifyOrder
impl ModifyOrder
Sourcepub const fn builder(
account_id: AccountId,
order_id: OrderId,
) -> ModifyOrderBuilder
pub const fn builder( account_id: AccountId, order_id: OrderId, ) -> ModifyOrderBuilder
Starts a validated order-modification request.
Sourcepub const fn account_id(&self) -> AccountId
pub const fn account_id(&self) -> AccountId
Returns the provider account.
Sourcepub const fn limit_price(&self) -> Option<Decimal>
pub const fn limit_price(&self) -> Option<Decimal>
Returns the optional replacement limit price.
Sourcepub const fn stop_price(&self) -> Option<Decimal>
pub const fn stop_price(&self) -> Option<Decimal>
Returns the optional replacement stop price.
Sourcepub const fn trail_price(&self) -> Option<Decimal>
pub const fn trail_price(&self) -> Option<Decimal>
Returns the optional absolute replacement price level for a trailing stop.
This input differs from the distance returned in Order::trail_price.