#[non_exhaustive]pub struct RateLimit { /* private fields */ }Expand description
One rolling-window request limit.
Implementations
Sourceimpl RateLimit
impl RateLimit
Sourcepub fn new(max_requests: usize, window: Duration) -> Result<Self, Error>
pub fn new(max_requests: usize, window: Duration) -> Result<Self, Error>
Creates a non-zero rolling-window request limit.
Errors
Returns Error::Configuration when max_requests or window is
zero, or when the duration cannot be represented by a monotonic clock.
Sourcepub const fn max_requests(self) -> usize
pub const fn max_requests(self) -> usize
Returns the maximum admitted requests in the rolling window.