pub struct SessionValidator { /* private fields */ }Expand description
Guard for a periodic token-validation task.
Implementations
Sourceimpl SessionValidator
impl SessionValidator
Sourcepub async fn shutdown(self) -> Result<(), Error>
pub async fn shutdown(self) -> Result<(), Error>
Cancels validation and waits for its task to finish.
Errors
Returns the terminal validation error if the provider invalidated the
session, Error::AmbiguousSessionValidation when shutdown cancels an
admitted validation request, or Error::BackgroundTaskFailed if the
library-owned task panicked or was aborted unexpectedly.
Sourcepub fn is_finished(&self) -> bool
pub fn is_finished(&self) -> bool
Returns whether the validation task has stopped.