pub struct RealtimeEventReceiver { /* private fields */ }Expand description
Single-consumer bounded receiver for real-time events.
Implementations
Sourceimpl RealtimeEventReceiver
impl RealtimeEventReceiver
Sourcepub async fn recv(&mut self) -> Option<RealtimeEvent>
pub async fn recv(&mut self) -> Option<RealtimeEvent>
Receives the next accepted event or the ordered transport-gap marker.
Sourcepub fn acknowledge_transport_gap(&mut self)
pub fn acknowledge_transport_gap(&mut self)
Allows reconnect after the caller has installed its recovery fence.